pub struct VerifyingKey { /* private fields */ }Expand description
A verifying key that can authenticate signed messages.
Constructed from the same shared secret as the SigningKey.
Implementations
Sourceimpl VerifyingKey
impl VerifyingKey
Sourcepub fn from_secret(secret: &str) -> Self
pub fn from_secret(secret: &str) -> Self
Derive a verifying key from the same shared secret used to create the
SigningKey.