RemoteBridge

Struct RemoteBridge 

pub struct RemoteBridge {
    pub state: Arc<RwLock<BridgeState>>,
    pub device_status: Arc<RwLock<Option<DeviceStatus>>>,
    pub org_policies: Arc<RwLock<Option<OrgPolicies>>>,
    pub permission_relay: PermissionRelay,
    /* private fields */
}
Remote control bridge

Maintains communication with the backend using either Supabase Realtime (preferred) or HTTP polling (fallback).

Fields

state: Arc<RwLock<BridgeState>>

Current bridge connection state.

device_status: Arc<RwLock<Option<DeviceStatus>>>

Device allowlist status from last authentication.

org_policies: Arc<RwLock<Option<OrgPolicies>>>

Organization policies from last authentication.

permission_relay: PermissionRelay

Permission relay for remote tool-approval prompts.

Implementations

Source

impl RemoteBridge

pub fn new( config: BridgeConfig, agent_spawner: Option<Arc<dyn AgentSpawner>>, ) -> Self

Create a new remote bridge

Arguments
  • config - Bridge configuration with all injected platform values
  • agent_spawner - Optional agent spawner for remote agent creation
pub async fn connection_mode(&self) -> ConnectionMode

Get current connection mode

pub async fn state(&self) -> BridgeState

Get current bridge state

pub async fn is_ready(&self) -> bool

Check if bridge is connected and authenticated

pub async fn user_id(&self) -> Option<String>

Get the user ID (if authenticated)

pub async fn protocol_version(&self) -> String

Get the negotiated protocol version

pub async fn has_capability(&self, cap: ProtocolCapability) -> bool

Check if a capability is enabled in the negotiated protocol

pub async fn enabled_capabilities(&self) -> Vec<ProtocolCapability>

Get all enabled capabilities

pub async fn send_permission_request( &self, agent_id: &str, tool_name: &str, action: &str, details: Value, ) -> Result<PermissionDecision>

Send a permission request to the remote user and wait for their decision.

Returns Ok(decision) if the user responds within the timeout, or Ok(PermissionDecision { approved: false, .. }) on timeout.

pub fn set_shutdown_tx(&mut self, tx: Sender<()>)

Set the shutdown signal sender (for external shutdown control)

pub async fn run(&mut self) -> Result<()>

Connect to the backend and run the main communication loop

pub async fn shutdown(&mut self)

Shutdown the bridge