BackendCommand

Enum BackendCommand 

pub enum BackendCommand {
Show 15 variants Authenticated { session_token: String, user_id: String, refresh_interval_secs: u32, protocol: Option<ProtocolAccept>, device_status: Option<DeviceStatus>, org_policies: Option<OrgPolicies>, }, SendInput { command_id: String, agent_id: String, content: String, }, SlashCommand { command_id: String, agent_id: String, command: String, args: Vec<String>, }, CancelOperation { command_id: String, agent_id: String, }, Subscribe { agent_id: String, }, Unsubscribe { agent_id: String, }, SpawnAgent { command_id: String, model: Option<String>, working_directory: Option<String>, }, RequestSync, Ping { timestamp: i64, }, Disconnect { reason: String, }, AuthenticationFailed { error: String, }, AttachmentUpload { command_id: String, agent_id: String, attachment_id: String, filename: String, mime_type: String, size: u64, compressed: bool, compression_algorithm: Option<CompressionAlgorithm>, chunks_total: u32, }, AttachmentChunk { attachment_id: String, chunk_index: u32, data: String, is_final: bool, }, PermissionResponse { request_id: String, approved: bool, remember_for_session: bool, always_allow: bool, }, AttachmentComplete { attachment_id: String, checksum: String, },
}
Messages FROM Backend TO CLI

Variants



Authenticated

Authenticated - here’s your session token and negotiated protocol

Fields

session_token: String

Session token for subsequent requests.

user_id: String

Authenticated user ID.

refresh_interval_secs: u32

Interval in seconds between heartbeats.

protocol: Option<ProtocolAccept>

Negotiated protocol (optional for backward compatibility)

device_status: Option<DeviceStatus>

Device allowlist status returned by backend.

org_policies: Option<OrgPolicies>

Organization-level policies (enforced client-side, verified server-side).



SendInput

Send input to an agent

Fields

command_id: String

Unique command identifier.

agent_id: String

Target agent ID.

content: String

Input content to send.



SlashCommand

Execute slash command on agent

Fields

command_id: String

Unique command identifier.

agent_id: String

Target agent ID.

command: String

Slash command name.

args: Vec<String>

Command arguments.



CancelOperation

Cancel current operation

Fields

command_id: String

Unique command identifier.

agent_id: String

Target agent ID.



Subscribe

Subscribe to agent stream

Fields

agent_id: String

Agent ID to subscribe to.



Unsubscribe

Unsubscribe from agent stream

Fields

agent_id: String

Agent ID to unsubscribe from.



SpawnAgent

Spawn new agent

Fields

command_id: String

Unique command identifier.

model: Option<String>

Model to use for the new agent.

working_directory: Option<String>

Working directory for the new agent.



RequestSync

Request full sync of all agents



Ping

Ping to check connection health

Fields

timestamp: i64

Timestamp for round-trip measurement.



Disconnect

Disconnect (server closing)

Fields

reason: String

Reason for disconnection.



AuthenticationFailed

Authentication failed

Fields

error: String

Error message describing the failure.



AttachmentUpload

Start of an attachment upload

Fields

command_id: String

Unique command identifier.

agent_id: String

Target agent ID.

attachment_id: String

Unique ID for this attachment

filename: String

Original filename

mime_type: String

MIME type (e.g., “text/plain”, “image/png”)

size: u64

Total size in bytes (uncompressed)

compressed: bool

Whether the data is compressed

compression_algorithm: Option<CompressionAlgorithm>

Compression algorithm used (if compressed)

chunks_total: u32

Total number of chunks



AttachmentChunk

A chunk of attachment data

Fields

attachment_id: String

Attachment ID this chunk belongs to

chunk_index: u32

Chunk index (0-based)

data: String

Base64-encoded data

is_final: bool

Whether this is the final chunk



PermissionResponse

Response to a permission request from the remote user

Fields

request_id: String

The request_id from the original PermissionRequest.

approved: bool

Whether the tool execution was approved.

remember_for_session: bool

Remember this decision for the rest of the session.

always_allow: bool

If true, always allow this tool (no future prompts).



AttachmentComplete

Attachment upload complete - verify checksum

Fields

attachment_id: String

ID of the completed attachment.

checksum: String

SHA-256 checksum of the complete (uncompressed) file