pub fn validate_session_token(
sessions_dir: &Path,
session_id: &str,
provided_token: &str,
) -> boolExpand description
Validate that a provided token matches the stored token for a session Returns true if tokens match, false if they don’t match or no token exists