pub fn write_session_token(
sessions_dir: &Path,
session_id: &str,
token: &str,
) -> Result<()>Expand description
Write session token to disk with secure permissions (0600) This should only be called by the agent process that owns the session