IpcConnection

Struct IpcConnection 

pub struct IpcConnection {
    pub reader: IpcReader,
    pub writer: IpcWriter,
}
IPC connection handle (combines reader and writer)

Fields

reader: IpcReader

The reader half of the connection.

writer: IpcWriter

The writer half of the connection.

Implementations

Source

impl IpcConnection

pub fn from_stream(stream: UnixStream) -> Self

Create an IPC connection from a Unix stream

pub async fn connect(socket_path: &Path) -> Result<Self>

Connect to an agent socket by path

pub async fn connect_to_agent( sessions_dir: &Path, session_id: &str, ) -> Result<Self>

Connect to an agent by session ID, looking up the socket in sessions_dir

pub fn split(self) -> (IpcReader, IpcWriter)

Split into reader and writer

pub fn upgrade_to_encrypted(self, session_token: &str) -> EncryptedIpcConnection

Upgrade to encrypted connection using the session token

This should be called after the handshake is complete and both sides have agreed on the session token.